==> haskell-hspec-smallcheck-0.4.2-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.4.2
id: hspec-smallcheck-0.4.2-9aJNy4N4VV89XVb7yslc2h
key: hspec-smallcheck-0.4.2-9aJNy4N4VV89XVb7yslc2h
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.SmallCheck
abi: 50829adcf2a4b0c1194e53fa0b71167f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-smallcheck-0.4.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-smallcheck-0.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/hspec-smallcheck-0.4.2
hs-libraries: HShspec-smallcheck-0.4.2-9aJNy4N4VV89XVb7yslc2h
depends:
    base-4.10.0.0 hspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa
    smallcheck-1.1.2-4gPZcheDqS6L156DM7moIy
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             hspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa=3be6fb82e0339beae8374ee96f9b594c
             smallcheck-1.1.2-4gPZcheDqS6L156DM7moIy=ece817205c7d3d3b888b9521bb34f2bb
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.4.2-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.4.2
id: hspec-smallcheck-0.4.2-7XW47Lr08WfJzugJV4dGzT
key: hspec-smallcheck-0.4.2-7XW47Lr08WfJzugJV4dGzT
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.SmallCheck
abi: 3a7cebf54bc44c1715efd90ac1a03eae
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-smallcheck-0.4.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-smallcheck-0.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/hspec-smallcheck-0.4.2
hs-libraries: HShspec-smallcheck-0.4.2-7XW47Lr08WfJzugJV4dGzT
depends:
    base-4.10.0.0 hspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD
    smallcheck-1.1.2-4gPZcheDqS6L156DM7moIy
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             hspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD=00ce86a862e3e4cd41b1efba7f000608
             smallcheck-1.1.2-4gPZcheDqS6L156DM7moIy=ece817205c7d3d3b888b9521bb34f2bb
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
